@@ -10,7 +10,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2015 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2016 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -202,19 +202,20 @@ lex_comment(void)
     case '*':
     {
         char * pz = strstr(cctx->scx_scan+2, END_C_COMMENT);
-        if (pz != NULL) {
-            char * p = cctx->scx_scan+1;
-            for (;;) {
-                p = strchr(p+1, NL);
-                if ((p == NULL) || (p > pz))
-                    break;
-                cctx->scx_line++;
-            }
-            cctx->scx_scan = pz+2;
-            return SUCCESS;
+        if (pz == NULL)
+            break;
+
+        char * p = cctx->scx_scan+1;
+        for (;;) {
+            p = strchr(p+1, NL);
+            if ((p == NULL) || (p > pz))
+                break;
+            cctx->scx_line++;
         }
-        break;
+        cctx->scx_scan = pz+2;
+        return SUCCESS;
     }
+
     case '/':
     {
         char * pz = strchr(cctx->scx_scan+2, NL);
@@ -548,10 +549,10 @@ alist_to_autogen_def(void)
     /*
      *  The result *must* be a string, or we choke.
      */
-    if (! AG_SCM_STRING_P(res))
+    if (! scm_is_string(res))
         AG_ABEND(ALIST_TO_AG_ERR);
 
-    res_len   = AG_SCM_STRLEN(res);
+    res_len   = scm_c_string_length(res);
     processing_state = PROC_STATE_LOAD_DEFS;
     cctx->scx_scan = pzEnd;
     AGFREE(pzText);
